==> foundation-2.2.0.tgz: package/lib/esm/Row.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import { Children, createContext } from "react";
import Box from "./Box";
import Column from "./Column";
import useTheme from "./useTheme";
var alignments = {
    top: "flex-start",
    bottom: "flex-end",
    center: "center",
};
var context = createContext("md");
var Provider = context.Provider;
export var gapContext = context;
var Row = function (_a) {
    var children = _a.children, _b = _a.gap, gap = _b === void 0 ? "md" : _b, simple = _a.simple, _c = _a.alignY, alignY = _c === void 0 ? "top" : _c, props = __rest(_a, ["children", "gap", "simple", "alignY"]);
    var size = useTheme().size;
    return (_jsx(Box, __assign({ d: "flex", css: css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n        box-sizing: border-box;\n        align-items: ", ";\n        flex-wrap: nowrap;\n        margin: 0 -", "px;\n      "], ["\n        box-sizing: border-box;\n        align-items: ", ";\n        flex-wrap: nowrap;\n        margin: 0 -", "px;\n      "])), alignments[alignY], size(gap).raw / 2) }, props, { children: _jsx(Provider, __assign({ value: gap }, { children: simple
                ? Children.map(children, function (child) { return (_jsx(Column, __assign({ width: "expand" }, { children: child }))); })
                : children })) })));
};
export default Row;
var templateObject_1;

==> foundation-2.3.2.tgz: package/lib/esm/Row.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import { Children, createContext, forwardRef } from "react";
import Box from "./Box";
import Column from "./Column";
import useTheme from "./useTheme";
var alignments = {
    top: "flex-start",
    bottom: "flex-end",
    center: "center",
};
var context = createContext("md");
var Provider = context.Provider;
export var gapContext = context;
var Row = function (_a, ref) {
    var children = _a.children, _b = _a.gap, gap = _b === void 0 ? "md" : _b, simple = _a.simple, _c = _a.alignY, alignY = _c === void 0 ? "top" : _c, props = __rest(_a, ["children", "gap", "simple", "alignY"]);
    var size = useTheme().size;
    return (_jsx(Box, __assign({ ref: ref, d: "flex", css: css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n        box-sizing: border-box;\n        align-items: ", ";\n        flex-wrap: nowrap;\n        margin: 0 -", "px;\n      "], ["\n        box-sizing: border-box;\n        align-items: ", ";\n        flex-wrap: nowrap;\n        margin: 0 -", "px;\n      "])), alignments[alignY], size(gap).raw / 2) }, props, { children: _jsx(Provider, __assign({ value: gap }, { children: simple
                ? Children.map(children, function (child) { return (_jsx(Column, __assign({ width: "expand" }, { children: child }))); })
                : children })) })));
};
export default forwardRef(Row);
var templateObject_1;
